# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.3.3

([Full Changelog](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/compare/v0.3.2...17b4c0407502f6837b106cb917ca55d5c957644f))

### Maintenance and upkeep improvements

- Bump marked from 0.3.19 to 4.2.4 [#38](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/38) ([@dependabot](https://github.com/dependabot))
- Bump actions/checkout from 2 to 3 [#37](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/37) ([@dependabot](https://github.com/dependabot))
- Bump @jupyterlab/application from 3.5.1 to 3.6.1 [#36](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/36) ([@dependabot](https://github.com/dependabot))
- Bump typescript from 4.1.6 to 4.9.5 [#35](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/35) ([@dependabot](https://github.com/dependabot))
- Bump http-cache-semantics from 4.1.0 to 4.1.1 [#34](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/34) ([@dependabot](https://github.com/dependabot))
- Bump json5 from 1.0.1 to 1.0.2 [#32](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/32) ([@dependabot](https://github.com/dependabot))
- Bump stylelint-config-recommended from 6.0.0 to 9.0.0 [#31](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/31) ([@dependabot](https://github.com/dependabot))
- Bump stylelint from 14.16.0 to 14.16.1 [#30](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/30) ([@dependabot](https://github.com/dependabot))
- Bump eslint-plugin-prettier from 3.4.1 to 4.2.1 [#29](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/29) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/graphs/contributors?from=2022-12-30&to=2023-03-08&type=c))

[@ahgraber](https://github.com/search?q=repo%3Aninerealmlabs%2Fjupyterlab-theme-material-night-eighties+involves%3Aahgraber+updated%3A2022-12-30..2023-03-08&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Aninerealmlabs%2Fjupyterlab-theme-material-night-eighties+involves%3Adependabot+updated%3A2022-12-30..2023-03-08&type=Issues)

<!-- <END NEW CHANGELOG ENTRY> -->

## 0.3.2

([Full Changelog](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/compare/v0.3.1...6abafde8bdad82a2a8655f785a2e25d38458a47b))

### Enhancements made

- Add Features/tests [#26](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/26) ([@ahgraber](https://github.com/ahgraber))

### Bugs fixed

- Add Features/tests [#26](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/26) ([@ahgraber](https://github.com/ahgraber))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/graphs/contributors?from=2022-12-28&to=2022-12-30&type=c))

[@ahgraber](https://github.com/search?q=repo%3Aninerealmlabs%2Fjupyterlab-theme-material-night-eighties+involves%3Aahgraber+updated%3A2022-12-28..2022-12-30&type=Issues)

## 0.3.1

([Full Changelog](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/compare/v0.3.0...aea710ed3c58f06405ed21627d7658efd62766d0))

### Maintenance and upkeep improvements

- Bump @jupyterlab/builder from 3.5.1 to 3.5.2 [#25](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/25) ([@dependabot](https://github.com/dependabot))
- Bump @jupyterlab/apputils from 3.5.1 to 3.5.2 [#23](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/23) ([@dependabot](https://github.com/dependabot))
- Bump stylelint-config-standard from 24.0.0 to 29.0.0 [#22](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/22) ([@dependabot](https://github.com/dependabot))
- Bump eslint-config-prettier from 6.15.0 to 8.5.0 [#21](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/21) ([@dependabot](https://github.com/dependabot))
- Bump actions/download-artifact from 2 to 3 [#20](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/20) ([@dependabot](https://github.com/dependabot))
- Bump actions/upload-artifact from 2 to 3 [#19](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/19) ([@dependabot](https://github.com/dependabot))
- Bump actions/setup-python from 2 to 4 [#18](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/18) ([@dependabot](https://github.com/dependabot))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/graphs/contributors?from=2022-12-15&to=2022-12-28&type=c))

[@ahgraber](https://github.com/search?q=repo%3Aninerealmlabs%2Fjupyterlab-theme-material-night-eighties+involves%3Aahgraber+updated%3A2022-12-15..2022-12-28&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Aninerealmlabs%2Fjupyterlab-theme-material-night-eighties+involves%3Adependabot+updated%3A2022-12-15..2022-12-28&type=Issues)

## 0.3.0

([Full Changelog](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/compare/d0979617daf4fa54da8ab66f75c68b46664c74b3...f508e45be12eabaae8ab2b07168bce4ea4c8fff4))

### Merged PRs

- Dependency updates [#16](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/16) ([@ahgraber](https://github.com/ahgraber))
- Bump ansi-regex from 5.0.0 to 5.0.1 [#9](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/9) ([@dependabot](https://github.com/dependabot))
- Bump node-fetch from 2.6.1 to 2.6.7 [#8](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/8) ([@dependabot](https://github.com/dependabot))
- Bump url-parse from 1.5.3 to 1.5.10 [#7](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/7) ([@dependabot](https://github.com/dependabot))
- Bump nanoid from 3.1.23 to 3.2.0 [#5](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/5) ([@dependabot](https://github.com/dependabot))
- Bump url-parse from 1.5.1 to 1.5.3 [#4](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/4) ([@dependabot](https://github.com/dependabot))
- Bump tar from 6.1.5 to 6.1.11 [#3](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/3) ([@dependabot](https://github.com/dependabot))
- Bump tar from 6.1.0 to 6.1.5 [#2](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/2) ([@dependabot](https://github.com/dependabot))
- Update build.yml [#1](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/1) ([@ahgraber](https://github.com/ahgraber))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/graphs/contributors?from=2021-06-17&to=2022-12-15&type=c))

[@ahgraber](https://github.com/search?q=repo%3Aninerealmlabs%2Fjupyterlab-theme-material-night-eighties+involves%3Aahgraber+updated%3A2021-06-17..2022-12-15&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Aninerealmlabs%2Fjupyterlab-theme-material-night-eighties+involves%3Adependabot+updated%3A2021-06-17..2022-12-15&type=Issues)

## 0.2.11

([Full Changelog](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/compare/d0979617daf4fa54da8ab66f75c68b46664c74b3...f508e45be12eabaae8ab2b07168bce4ea4c8fff4))

### Merged PRs

- Dependency updates [#16](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/16) ([@ahgraber](https://github.com/ahgraber))
- Bump ansi-regex from 5.0.0 to 5.0.1 [#9](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/9) ([@dependabot](https://github.com/dependabot))
- Bump node-fetch from 2.6.1 to 2.6.7 [#8](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/8) ([@dependabot](https://github.com/dependabot))
- Bump url-parse from 1.5.3 to 1.5.10 [#7](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/7) ([@dependabot](https://github.com/dependabot))
- Bump nanoid from 3.1.23 to 3.2.0 [#5](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/5) ([@dependabot](https://github.com/dependabot))
- Bump url-parse from 1.5.1 to 1.5.3 [#4](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/4) ([@dependabot](https://github.com/dependabot))
- Bump tar from 6.1.5 to 6.1.11 [#3](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/3) ([@dependabot](https://github.com/dependabot))
- Bump tar from 6.1.0 to 6.1.5 [#2](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/2) ([@dependabot](https://github.com/dependabot))
- Update build.yml [#1](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/pull/1) ([@ahgraber](https://github.com/ahgraber))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/ninerealmlabs/jupyterlab-theme-material-night-eighties/graphs/contributors?from=2021-06-17&to=2022-12-15&type=c))

[@ahgraber](https://github.com/search?q=repo%3Aninerealmlabs%2Fjupyterlab-theme-material-night-eighties+involves%3Aahgraber+updated%3A2021-06-17..2022-12-15&type=Issues) | [@dependabot](https://github.com/search?q=repo%3Aninerealmlabs%2Fjupyterlab-theme-material-night-eighties+involves%3Adependabot+updated%3A2021-06-17..2022-12-15&type=Issues)

## v0.2.10

- improve text highlighting

## v0.2.9

- bump dependencies

## v0.2.8

- clean up readme
- republish pipy and npm

## v0.2.7

- resolve css/index error

## ...

## v0.2.1

- update jupyterlab>=3.1.\*
